@@ -25,7 +25,7 @@
 
 #include <glib.h>
 #include <glib/gstdio.h>
-#include <gjs/gjs.h>
+#include <gjs/gjs-module.h>
 #include <util/crash.h>
 #include <locale.h>
 
@@ -47,11 +47,18 @@ setup(GjsTestJSFixture *fix,
     int code;
     char *filename;
     char *search_path[2];
+    const char *test_filename = test_data;
+    const char *js_version;
+
+    js_version = gjs_context_scan_file_for_js_version(test_filename);
 
     search_path[0] = g_build_filename(top_srcdir, "test", "modules", NULL);
     search_path[1] = NULL;
 
-    fix->context = gjs_context_new_with_search_path(search_path);
+    fix->context = g_object_new (GJS_TYPE_CONTEXT,
+                                 "search-path", search_path,
+                                 "js-version", js_version,
+                                 NULL);
     g_free(search_path[0]);
 
     /* Load jsUnit.js directly into global scope, rather than
@@ -89,7 +96,26 @@ test(GjsTestJSFixture *fix,
     if (!success)
         g_error("%s", error->message);
     g_assert(error == NULL);
-    g_assert_cmpint(code, ==, 0);
+    if (code != 0)
+        g_error("Test script returned code %d; assertions will be in gjs.log", code);
+}
+
+static GSList *
+read_all_dir_sorted (const char *dirpath)
+{
+    GSList *result = NULL;
+    GDir *dir;
+    const char *name;
+
+    dir = g_dir_open(dirpath, 0, NULL);
+    g_assert(dir != NULL);
+
+    while ((name = g_dir_read_name(dir)) != NULL)
+        result = g_slist_prepend (result, g_strdup (name));
+    result = g_slist_sort(result, (GCompareFunc) strcmp);
+
+    g_dir_close(dir);
+    return result;
 }
 
 int
@@ -109,10 +135,9 @@ main(int argc, char **argv)
     char *gjs_unit_dir;
     char *top_builddir;
     char *data_home;
-    const char *name;
     GString *path;
-    GDir *dir;
     size_t i;
+    GSList *all_tests, *iter;
 
     working_dir = g_get_current_dir();
 
@@ -157,8 +182,20 @@ main(int argc, char **argv)
     g_setenv("BUILDDIR", top_builddir, FALSE);
     g_setenv("XDG_DATA_HOME", data_home, FALSE);
     g_setenv("GJS_PATH", path->str, FALSE);
+    /* The tests are known to fail in the presence of the JIT;
+     * we leak objects.
+     * https://bugzilla.gnome.org/show_bug.cgi?id=616193
+     */
+    g_setenv("GJS_DISABLE_JIT", "1", FALSE);
 
-    gjs_crash_after_timeout(60*7); /* give the unit tests 7 minutes to complete */
+    {
+        const char *timeout_str = g_getenv("GJS_TEST_TIMEOUT");
+        if (timeout_str != NULL) {
+            guint timeout = (guint)g_ascii_strtoull(timeout_str, NULL, 10);
+            if (timeout > 0)
+                gjs_crash_after_timeout(timeout);
+        }
+    }
     gjs_init_sleep_on_crash();
 
     setlocale(LC_ALL, "");
@@ -168,10 +205,10 @@ main(int argc, char **argv)
 
     /* iterate through all 'test*.js' files in ${top_srcdir}/test/js */
     js_test_dir = g_build_filename(top_srcdir, "test", "js", NULL);
-    dir = g_dir_open(js_test_dir, 0, NULL);
-    g_assert(dir != NULL);
 
-    while ((name = g_dir_read_name(dir)) != NULL) {
+    all_tests = read_all_dir_sorted(js_test_dir);
+    for (iter = all_tests; iter; iter = iter->next) {
+        char *name = iter->data;
         char *test_name;
         char *file_name;
 
@@ -185,10 +222,11 @@ main(int argc, char **argv)
 
         file_name = g_build_filename(js_test_dir, name, NULL);
         g_test_add(test_name, GjsTestJSFixture, file_name, setup, test, teardown);
+        g_free(name);
         g_free(test_name);
         /* not freeing file_name as it's needed while running the test */
     }
-    g_dir_close(dir);
+    g_slist_free(all_tests);
 
     return g_test_run ();
 }
